package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````U!4``#0````X@0````0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````.'P`
M`#A\```%```````!``$```#`?0``P'T!`,!]`0!\`@``K!(```8```````$`
M`@```,A]``#(?0$`R'T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3`?0``P'T!`,!]`0!``@``0`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$\````(````"```
M``&0$``E0`2`*(`0!:"&4(2``0``"R`$C3B`$D&*!`@(3P```%````!4````
M60```%H```!A````8@```&,`````````90```&8`````````9P```&@```!K
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!6.^7>;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FH:GE"_VE<;H^#[20``````````
M````````````````8!`````````#``<```````"``0```````P`1``P`````
M`````````!(```#:`0`````````````2````%```````````````$0`````"
M`````````````!$```!\`0`````````````2````&P``````````````$@``
M`+D!`````````````!(````C```````````````2````*@``````````````
M$@````T"`````````````!(```#%`0`````````````2````,P``````````
M````(````$X#`````````````"$```!+```````````````2````40``````
M````````$@```%@``````````````!(````;`P`````````````2````#`,`
M````````````$@```)("`````````````!(```!?```````````````2````
M,P(`````````````$@```&8``````````````!(```#'`@`````````````2
M````;0``````````````$@```'4``````````````!(```"P`@``````````
M```2````?0``````````````$@```(,``````````````!(```",````````
M```````@````!0,`````````````$@```*@``````````````!(```"M````
M```````````2````'@(`````````````$0```,X"`````````````!(```!@
M`@`````````````2````M```````````````$@```%("`````````````!(`
M``!R`P`````````````2````V0(`````````````$0```$T#````````````
M`!$```"$`@`````````````2````.@,`````````````$@```$\#````````
M`````!$```"[```````````````2````,@,`````````````$@```,0`````
M`````````!$```"*`0`````````````2````U@``````````````(@```.4`
M`````````````"````#[```````````````2````_0(`````````````$@``
M`'`"`````````````!(``````0`````````````2````!@$`````````````
M(````+L"`````````````!(````@`0`````````````2````J@$`````````
M````$@```"4!`````````````!(```"@`@`````````````2````F0$`````
M````````$@```"L!`````````````!(````\`0`````````````2````+@(`
M````````````$@```'X``````````````!(````_`@`````````````2````
M>0(`````````````$@```"L#`````````````!(```!"`0`````````````2
M````(P,`````````````$@```%8!`````````````!(````I`@``````````
M```2````Z`$`````````````$@```%T!`````````````!(```!D`0``````
M```````2````3`,`````````````(0```'4!`````````````!(```!R!```
M;)`!```````0`!(`1P,``&@3``!L`@``$@`)`/H!``#@/@``!````!(`"@"T
M`P``G"4``+`&```2``D`@@0``-`O``!8````$@`)`)$#```$'P``!````!(`
M"0`F!```8!````0````2``<`UP,``$PL``"$`P``$@`)`"P$```\@`$`````
M`!``$@!:!```"!\``"0"```2``D`#P0``#R``0``````$``2`*(#``#H)```
MM````!(`"0#!`P``!!T``%P````2``D`R0,``&@D``!H````$@`)`.T#``!D
M/```1`$``!(`"0`"!```+"$``!P````2``D`&P0``&R0`0``````$``2`'T$
M``!LD`$``````!``$@!7`P``^!4``%P````2``D`.@0``$@A```$`0``$@`)
M`/@#```X@`$`!````!$`$0!3!```/(`!```````0`!$`%`0``-05````````
M$@`)`",$```4/```4````!(`"0!@`P``T"0``!@````2``D`>P,``,P=```X
M`0``$@`)`&<$``"H/0``.`$``!(`"0!Q!```;)`!```````0`!(`1@0``$PB
M```<`@``$@`)``!L:6)P97)L+G-O`&]P96YD:7(`<W1D97)R`')E86QL;V,`
M86-C97-S`'-N<')I;G1F`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O`&QS965K
M`&=E='!I9`!S=')C;7``;65M<V5T`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``
M;'-T870`8VQO<V5D:7(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P
M96X`<W1R<W1R`'-T<F-H<@!R96%D;&EN:P!?7W-T86-K7V-H:U]G=6%R9`!?
M7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!C;&]S
M90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]E<G)N
M;U]L;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P96-I9FEC`&UE;6-P>0!S
M=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!0
M97)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T
M`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI
M9G0`4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?
M;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V
M7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F,N;75S;"UA
M<FUH9BYS;RXQ`&9P<FEN=&8`<W1R9'5P`'!T:')E861?871F;W)K`')E861D
M:7(`<W!R:6YT9@!S=')T;VL`<W1R;F-P>0!?7VQI8F-?<W1A<G1?;6%I;@!?
M7U]E;G9I<F]N`%]S=&%R=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S
M971U<%]L:6)P871H`'!A<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE
M86X`6%-?26YT97)N86QS7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L
M`'!A<E]B87-E;F%M90!?7V)S<U]S=&%R=`!?7V5N9%]?`'-H85]I;FET`%]?
M8G-S7W-T87)T7U\`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV`%]E9&%T80!P
M87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]?8G-S7V5N9%]?`%]E;F0`<&%R7V-L
M96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4`P'T!`!<```#$
M?0$`%P```+Q_`0`7````R'\!`!<```#4?P$`%P````"``0`7````"(`!`!<`
M```,@`$`%P```!2``0`7````&(`!`!<````<@`$`%P```""``0`7````)(`!
M`!<````L@`$`%P```#"``0`7````.(`!`!<```#`?P$`%04``,1_`0`5!@``
MS'\!`!4.``#0?P$`%1\``-A_`0`5(P``W'\!`!4I``#@?P$`%2T``.1_`0`5
M,```Z'\!`!4R``#L?P$`%3,``/!_`0`5.```]'\!`!4]``#X?P$`%3X``/Q_
M`0`50P``Q'X!`!8#``#(?@$`%@0``,Q^`0`6!P``T'X!`!8(``#4?@$`%@D`
M`-A^`0`6"@``W'X!`!8+``#@?@$`%@P``.1^`0`6#0``Z'X!`!8.``#L?@$`
M%A```/!^`0`6$0``]'X!`!82``#X?@$`%A,``/Q^`0`6%````'\!`!85```$
M?P$`%A8```A_`0`6%P``#'\!`!88```0?P$`%AD``!1_`0`6&@``&'\!`!8;
M```<?P$`%AP``"!_`0`6'0``)'\!`!8>```H?P$`%B```"Q_`0`6(0``,'\!
M`!8B```T?P$`%B0``#A_`0`6)0``/'\!`!8F``!`?P$`%B<``$1_`0`6*```
M2'\!`!8K``!,?P$`%BP``%!_`0`6+@``5'\!`!8O``!8?P$`%C$``%Q_`0`6
M,@``8'\!`!8S``!D?P$`%C0``&A_`0`6-0``;'\!`!8V``!P?P$`%C<``'1_
M`0`6.0``>'\!`!8Z``!\?P$`%CL``(!_`0`6/```A'\!`!8_``"(?P$`%D``
M`(Q_`0`600``D'\!`!9"``"4?P$`%D0``)A_`0`610``G'\!`!9&``"@?P$`
M%D<``*1_`0`62```J'\!`!9)``"L?P$`%DH``+!_`0`62P``M'\!`!9,``"X
M?P$`%DX```%`+>D!0+WH'O\OX03@+>4$X)_E#N"/X`CPON4\;@$``,:/XA;*
MC.(\_KSE`,:/XA;*C.(T_KSE`,:/XA;*C.(L_KSE`,:/XA;*C.(D_KSE`,:/
MXA;*C.(<_KSE`,:/XA;*C.(4_KSE`,:/XA;*C.(,_KSE`,:/XA;*C.($_KSE
M`,:/XA;*C.+\_;SE`,:/XA;*C.+T_;SE`,:/XA;*C.+L_;SE`,:/XA;*C.+D
M_;SE`,:/XA;*C.+<_;SE`,:/XA;*C.+4_;SE`,:/XA;*C.+,_;SE`,:/XA;*
MC.+$_;SE`,:/XA;*C.*\_;SE`,:/XA;*C.*T_;SE`,:/XA;*C.*L_;SE`,:/
MXA;*C.*D_;SE`,:/XA;*C.*<_;SE`,:/XA;*C.*4_;SE`,:/XA;*C.*,_;SE
M`,:/XA;*C.*$_;SE`,:/XA;*C.)\_;SE`,:/XA;*C.)T_;SE`,:/XA;*C.)L
M_;SE`,:/XA;*C.)D_;SE`,:/XA;*C.)<_;SE`,:/XA;*C.)4_;SE`,:/XA;*
MC.),_;SE`,:/XA;*C.)$_;SE`,:/XA;*C.(\_;SE`,:/XA;*C.(T_;SE`,:/
MXA;*C.(L_;SE`,:/XA;*C.(D_;SE`,:/XA;*C.(<_;SE`,:/XA;*C.(4_;SE
M`,:/XA;*C.(,_;SE`,:/XA;*C.($_;SE`,:/XA;*C.+\_+SE`,:/XA;*C.+T
M_+SE`,:/XA;*C.+L_+SE`,:/XA;*C.+D_+SE`,:/XA;*C.+<_+SE`,:/XA;*
MC.+4_+SE`,:/XA;*C.+,_+SE`,:/XA;*C.+$_+SE`,:/XA;*C.*\_+SE`,:/
MXA;*C.*T_+SE`,:/XA;*C.*L_+SE`,:/XA;*C.*D_+SE`,:/XA;*C.*<_+SE
M`,:/XA;*C.*4_+SE`,:/XA;*C.*,_+SE`,:/XA;*C.*$_+SE`,:/XA;*C.)\
M_+SE`,:/XA;*C.)T_+SE`,:/XA;*C.)L_+SE`,:/XA;*C.)D_+SE`,:/XA;*
MC.)<_+SE`,:/XA;*C.)4_+SE<$`MZ2#03>(<`(WE&!"-Y10@C>48$(WB%""-
MXAP`C>+X09_EJO__Z_0QG^4$0(_@`S"4YPPPC>7H,9_E#""=Y0,PE.<"$*#A
M`P"@X1`PC>5:___KT#&?Y0,PE.<`8-/ER#&?Y0``5N,#4)3G"P``&GS__^NX
M(9_E``!0XP(@C^`0`(+E`0``&@$`H..9___KJO__ZP``E>7`___K/6?`Y0``
ME>6]___KGC/0Y0(P@^.>,\#E``"5Y;C__^N>,]#E`3"#XYXSP.4<`)WE!0"`
MX@<!<.,&``":6#&?Y5@!G^4#,)3G``"/X`,0H.$,,(WE(/__ZP`!H.&*___K
M&,"=Y3@AG^4`$)SE`B"/X``0@.4L$9_E"`""Y0$0C^`$$(#E(!&?Y0`PH.$!
M$(_@`!"1Y0@0@.40$9_E`1"/X`P0H.4$$*#C!!""Y0$0H.,<()WE`0!2X2T`
M`,H`$*#C#0&"XNA`G^4`$8/G`!"-Y>`0G^4$0(_@`R""X@$0C^`0`)3E)O__
MZP!04.("```:$`"4Y5[__^L`4*#AN$"?Y01`C^`0`)3E/O__ZZP`G^4``(_@
MW```ZP``4.,,```:##"4Y0``4^,#```:D`"?Y0``C^#4``#K#`"$Y80PG^4#
M,(_@#`"3Y0``4.,````*G08`ZW`PG^4#,(_@$`"3Y7#__^O*_O_K!0"@X2#0
MC>)P@+WH`>&<YP$0@>($X*#ER___ZAQK`0!$`0``0`$```P!```@`0``;&P!
M`"0!```'*P``X&L!`"8M``"@:P$`"2T``'AK`0!X"```3&L!`)$J```F*@``
M#&L!`/1J`0``L*#C`."@XQ`0G^4!$(_@#0"@X0_`P.,,T*#A````Z^!G`0`?
M0"WI0#"?Y4`@G^4#,(_@`B"3YP@@C>4T()_E`B"3YPP@C>4`(*#C!""-Y20@
MG^4",)/G!""`X@`PC>4`$)#E"#"=Y0P`G>7T_O_KK&@!`!P!```$`0``$`$`
M`$``G^5`,)_E0""?Y0``C^`#,(_@``!3X0(@C^`>_R\!+#"?Y0C03>(#,)+G
M!#"-Y0``4^,!```*"-"-XA/_+^$(T(WB'O\OX=1I`0#0:0$`1&@!`!@!``!,
M`)_E3#"?Y0``C^`#,(_@`!!#X$$1H.$\()_EH1^!X,$0L.$"((_@'O\O`2PP
MG^4(T$WB`S"2YP0PC>4``%/C`0``"@C0C>(3_R_A"-"-XA[_+^&`:0$`?&D!
M`.!G`0`X`0``:#"?Y1!`+>D#,(_@`##3Y5Q`G^4``%/C!$"/X!"`O1A0,)_E
M`S"4YP``4^,"```*1#"?Y0,`G^>^_O_KP/__ZS@PG^4#,)3G``!3XP(```HL
M`)_E``"/X%_^_^L!(*#C(#"?Y0,PC^``(,/E$("]Z!QI`0"(9P$`,`$``+1H
M`0`4`0``R&0``,!H`0`P,)_E,""?Y0,PC^`",)/G``!3XP8```H00"WI'!"?
MY1P`G^4!$(_@``"/X*'^_^L00+WHM?__Z@QG`0`T`0``>&@!`&AD``"<,)_E
M\$<MZ0!@4.(#,(_@!D"@`2````J(()_E`C"3YP!`D^4``%3C&P``"@8PH.$#
M4*#A`2#3Y```4N,]`%(3^O__&@&@H.$$@*#A!E!%X`APH.$$D)CD``!9XPE`
MH`$-```*!2"@X080H.$)`*#A2/[_ZP``4./T__\:!3#9YST`4^/Q__\:!$!'
MX$1!H.$`0(KE`4"%X@1`B>`$`*#A\(>]Z,!F`0`H`0``$T`MZ30PG^4T()_E
M`S"/X`)`D^<-$*#A`#"4Y00PC>7+___K!""=Y0`PE.4#`%+A````"J'^_^L(
MT(WB$("]Z!1F`0`L`0``]T`MZ0!@H.$-<*#A:$"?Y6@PG^4$0(_@`U"4YP`P
ME>4$,(WE!Q"@X08`H.&V___K``!0XP0``!H$()WE`#"5Y0,`4N$*```*BO[_
MZS`PG^4`()WE`S"4YP`PD^4",8/@!""3Y0``4N,$((/D^___&NO__^H,T(WB
M\("]Z,1E`0`L`0``*`$``/!/+>D!4*#AN)&?Y;@QG^4)D(_@`S"9YQ303>(`
M,(WE`#"3Y0!PH.$,,(WE`##1Y3T`4^,!4($"!0"@X6C^_^L($(WB`("@X0<`
MH.&,___K`$!0X@X```IA_O_K"`!0X3,``#H!0$3B`3#5Y```4^,!,.3E^___
M&@``H.,`,)WE#""=Y0`PD^4#`%+A2P``"E;^_^LT,9_E`Z"9YP"PFN4$,9OG
M``!3XPX``!H@,9_E`F"$X@,PC^``()/E!F&@X0``4N,)```*!A"@X0L`H.&;
M_?_K``!0XP``BN4/```:``#@X^3__^H!0(3BZ___Z@$@H.,&`*#A`""#Y<#]
M_^L`,%#B!#"-Y?3__PH(($;B"Q"@X;W]_^L$,)WE`#"*Y0`PFN4&8(/@`#"@
MXP0P!N4(0(WE!S"@X0,`H.$!(-/D``!2XST`4A/Z__\:?#"?Y0<`0.`#0)GG
M`H"(X@@`@.`(D)WE`&"4Y:7]_^L)`8;G``!0XP`PE!4(()T5`C&3%];__PH!
M(-?D`Q"@X3T`4N,``%(3`2#!Y`8``!H](*#C`"##Y0$@U>0``%+C`2#CY?O_
M_QJO___J`3"@X?#__^H4T(WB\(^]Z$!E`0`L`0``*`$``#QF`0#P3RWI*#&?
MY2@AG^4#,(_@`F"3YW303>(`,);E`%!0XFPPC>43```*`##5Y0``4^,0```*
M0_W_ZP!P4.(-```*]("?Y?20G^7TH)_E"("/X`F0C^`*H(_@!P"@X6#]_^L`
M`%#C"```&@<`H.%]_?_K!0"@X<#]_^ML()WE`#"6Y0,`4N$H```*XOW_ZQ-`
M@.(($*#A!`"@X4[]_^L``%#C[/__"@D0H.$$`*#A2?W_ZP``4./G__\*!0"@
MX=+]_^L`L*#A!`"@X<_]_^L``(O@`@"`XE3]_^L`L*#A!#"@X04@H.$*$*#A
MN_W_ZPT0H.$+`*#AK/W_ZP$`<.,+`*#A!P``"A`PG>4/.@/B`0E3XP,``!JY
M___K"P"@X9_]_^O,___J/?W_Z_K__^ITT(WB\(^]Z&QC`0`L`0``C2,``(@C
M``"'(P``,$`MZ7`PG^5P()_E`S"/X`)`D^=TT$WB`#"4Y0T0H.$`4*#A;#"-
MY3G]_^L``%#C``"@$PD``!H0,)WE#SH#X@H*4^,!"5,3!```&@(0H.,%`*#A
M^/S_ZQ`/;^&@`J#A;""=Y0`PE.4#`%+A````"I;]_^MTT(WB,("]Z"1B`0`L
M`0``$T`MZ3Q`G^4\,)_E!$"/X`,PE.<``)/E>?W_ZRPPG^4L$)_E`S"4YP$0
MC^`$,(WE(#"?Y00@G>4#,(_@"-"-XA!`O>AH_?_JH&$!`"`!```\`0``[2$`
M`*@A```30"WI3#"?Y4P@G^4#,(_@`D"3YP``E.5B_?_KX/__ZP``E.5?_?_K
M`""@XRPPG^4$((WE*!"?Y2@@G^4#,(_@`#"-Y0(@C^`!$(_@R/S_ZPC0C>(0
M@+WH1&$!`"`!```))```C2$``*`.``#P02WI&#&?Y1@AG^4#,(_@`G"3YP+:
M3>(8T$WB`BJ-X@`PE^44((+B`#""Y<'\_^OT,)_E]&"?Y?0@G^4#,(_@#("-
MX@`PC>4"((_@`#"@X080H.$(`*#AI_S_ZP$P@.(&`%/A````FO``\.<``%#C
M"```J@`PH.,#`*#A`CJ-XA0P@^(`()/E`#"7Y0,`4N$@```*.OW_ZP%:C>(0
M4(7B`2J@XP40H.$(`*#AZ?S_ZP!`4.+N__^Z`0"$XK7\_^L`,%#BZO__"@4`
M4^$"```J!""#X`(`5>'B__\Z!0!3X0(``)H$((7@`@!3X=W__SH&`%3AV___
MR@0@H.$#`*#A!1"@X1+]_^L`(*#C`#"@X00@P.?7___J`MJ-XAC0C>+P@;WH
MV&`!`"P!``!.(0```1```#8A``"P___J\$\MZ>@QG^7H(9_E`S"/X$+=3>("
M,)/G!-!-X@!`H.'4`9_E"#"-Y4$MC>(`,)/E/"""X@``C^`!4*#A`#""Y5#^
M_^LO$*#C`&"@X00`H.&B_/_K``!0XPP```J<`9_E!!"@X0``C^!Z_O_K03V-
MXCPP@^(`()/E"#"=Y00`H.$`,)/E`P!2X58```KM_/_K!`"@X>C\_^MD$9_E
M#`"-Y0$0C^`%`*#AT?S_ZP"`H.%0D9_E4+&?Y5"AG^4)D(_@"["/X```6./C
M__\*`"#8Y0``4N,)@*`!``!6XPD```H($*#A!@"@X4;\_^L``%#C!```&A@1
MG^4!$(_@O/S_ZP"`H.'N___J"`"@X<K\_^L`P*#C``"(X`@00.`!('#E+P!2
MXQ,```H,,)WE`2"#X@$@@N`*`%+AQ___RM0@G^6`<(WB`B"/X`101^(`((WE
M!$"-Y0@PH.$+(*#A`1J@XP4`H.$5_/_K`0"`X@$*4.,"``":\`#PYP#`P.7E
M___J$!"-X@4`H.&3_/_K``!0XQ```!I@,!?E#SH#X@()4^,,```:`1"@XP4`
MH.$`_/_K``!0XP<``!I<`)_E!1"@X0``C^`C_O_K!0"@X33\_^L`0*#AI/__
MZD`0G^4``*#C`1"/X,3__^I"W8WB!-"-XO"/O>B<7P$`+`$``!X@``#W'P``
MR!\``$T?``"!(```_P\``'`?```F'P``FQX``(@>````,*#A`2#3Y```4N,>
M_R\!+P!2XP,`H`'Y___J$$`MZ0!`4.("```*`##4Y0``4^,#```:U`"?Y0``
MC^`00+WH#OS_ZG/\_^L!`$#B``"$X```5.$`,*#A&@``*@`@T^4!`$#B+P!2
MX_C__PH#(*#A`1!2Y"\`4>,/```:`3!#X@,`5.$#(*#A`P``*@`0TN4!,$/B
M+P!1X_C__PH$($+@`C""X@$*4^,6``"*`2""X@$*4N,-``":\`#PYP(`5.$"
M,*#AZ/__.@,`5.'J__\:`##4Y2\`4^,T`)\%``"/`-7__PHL`)_E``"/X-+_
M_^HD,)_E!!"@X0,PC^`#`*#A__O_ZQ"`O>@``*#C$("]Z*T=```)'0``7AT`
M`$!>`0`P0"WIK#&?Y:PAG^4#,(_@+-!-X@)`D^<-(*#AG!&?Y0`PE.4!$(_@
M)#"-Y2K`@>(*,('B`N"@X0``D^4$$)/E"#"#X@,`KN@,`%/A#B"@X??__QJP
M,-/A9`&?Y;`PSN$``(_@B/W_ZU@!G^5849_E``"/X(3]_^M0`9_E!5"/X```
MC^"`_?_K1`&?Y0``C^!]_?_K/`&?Y0``C^!Z_?_K-`&?Y0``C^!W_?_K+`&?
MY0``C^!T_?_K)`&?Y0``C^!Q_?_K!0"@X6_]_^L4`9_E``"/X&S]_^L,`9_E
M``"/X&G]_^L$`9_E``"/X%3]_^L`$%#B`0``"@4`H.&$_?_K[`"?Y0``C^!-
M_?_K`!!0X@(```K<`)_E``"/X'S]_^O4`)_E``"/X$7]_^L`$%#B#```"L0`
MG^4``(_@=/W_Z[P0G^6\`)_E`1"/X```C^!O_?_K)""=Y0`PE.4#`%+A$@``
M"N;[_^N<`)_E``"/X#/]_^L`$%#BD`"?%0``CQ#M__\:B!"?Y0H@H.,!$(_@
M$0"-XF7[_^L``%#CY___&G``G^4;$(WB``"/X.+__^HLT(WB,("]Z%A<`0`L
M`0``=!P``,@<``#!'```\QP``+D<``"V'```L1P``+4<``!>'```J1P``*D<
M```['```FQP``)`<``".'```C1P``-8;``"5'```_1L``%4<``#I&P``1AP`
M`+T;```00"WI3#"?Y0,PC^``,)/E`0!SXPP``!H\`)_E``"/X`#]_^L``%#C
M!```"@``T.4P`%#C``!0$P$`H!,``*`#&#"?Y0,PC^```(/E$#"?Y0,`G^<0
M@+WHC%L!`"T;``!06P$`1%L!`!!`+>F@^__K2/O_ZP``4.,``)`5$("]Z/=`
M+>F8<)_E`$"@X0=PC^`'`*#AX_S_ZP!04.($$*#A`@``"@`PU>4``%/C!```
M&G``G^4``(_@#-"-XO!`O>@,_?_J)/O_ZP``4.,2```:!`"@X8#[_^L`8*#A
M!0"@X7W[_^L``(;@`@"`X@+[_^L`8*#A,#"?Y3`0G^4`4(WE`1"/X`,PC^`$
M(*#A9OO_ZP80H.$'`*#AYO__Z@S0C>+P@+WH-QL```\;```$&@``X1H``/!/
M+>DH5I_E*#:?Y050C^`#,)7G`ME-XOS03>(8QI_E%#"-Y0(IC>(`,)/E^$"-
MX@S`C^#T((+B`#""Y1!@C.)T,$3B7.!$X@!PH.$'`)SI!P"#Z`\`MN@/`*[H
M`P"6Z&@P1.(HP(SB`P".Z`<`G.@'`(/HQ`6?Y0``C^"<_/_K`&!0X@\```H`
M,-;E``!3XPP```JL___K!@"@X=OZ_^L`4*#A`CF-XO0P@^(`()/E%#"=Y04`
MH.$`,)/E`P!2X5@!``HZ^__KF?__ZP!@4.)HD$0"6```"@8`H.$Q^__K@`"@
MX0$`@.*V^O_K`+"@X0"0H.%(I9_E`6!&X@J@C^`!(/;E``!2XU$``!I<8$3B
M!*"6Y```6N,,```*"@"@X7/\_^L`D%#B^/__"@`PV>4``%/C]?__"FG]_^L`
M`%#C\O__"@D`H.&P^O_K`*"@X7201.(``%KC!0``&@1@F>0``%;C1P``"@`P
MUN4``%/C/```&@H`H.$*^__K`)"@X0L`H.$'^__K`)")X`&;B>($D(GB"0"@
MX8KZ_^L`8*#AH#2?Y:`4G^4#,(_@`#"-Y9@TG^4*(*#A`S"/X`$0C^`$L(WE
MZ_K_ZP<=H.,&`*#AUOK_ZP$`<.,L```:T/K_ZP`PD.41`%/C*```"F`DG^5@
M%)_E`@"5YP`PC>4`()?E!C"@X0$0C^```)#EK_K_ZP!0H..B___J-?S_ZP`P
M4.(%```*`##3Y0``4^,"```*=OK_ZP!@4.*F__\:!`"9Y```4./S__\:#&2?
MY09@C^"@___J"0"@X0H0H.'%^O_K`I")XJ7__^H&`*#A'/W_ZP``4..X__\*
M!@"@X6/Z_^L`H*#ALO__Z@:@H.&X___JX!!$X@8`H.%6^O_K`*!0X@@```JH
M,Y_EL!.?Y0,`E><`()?E!C"@X0$0C^```)#E@OK_Z]'__^K0,!3E#SH#X@$)
M4^/R__\:R+`4Y;?Z_^L``%OA[O__&M`P%.6#.Z#AHSN@X0<-4^/I__\:"0"@
MX3#Z_^L`4*#A5`.?Y0``C^#W^__K``!0XV$``!H`L)?E"P"@X9_Z_^L#`%#C
M`)"@X1H``)HL$Y_E!`!`X@$0C^```(O@"OK_ZP``4.,3```:!`!9XP,```H)
MD(O@!3!9Y2\`4^,-```:!'"7Y0``5^,*```*!P"@X8KZ_^L#`%#C!@``FN`2
MG^4$`$#B`1"/X```A^#V^?_K``!0XP>PH`')_O_K`)!0XG4``!H)$*#A"P"@
MX1CZ_^L`<%#B<```"@*@H.,`,.#C$2#@XP"@C>4$L$3BX/G_ZP8@H.,+$*#A
M!P"@X47Z_^L$,%3E``!3XS,``!H#,%3E0P!3XS```!H",%3E00!3XRT``!H!
M,%3E0P!3XRH``!H`,-3E2`!3XR<``!H!,-3E10!3XR0``!H`,.#C.2#@XP"@
MC>4'`*#AQ?G_ZRD@H.,+$*#A!P"@X2KZ_^L&(*#A$#*?Y1`2G^4#,(_@!#"-
MY0@RG^4`L(WE`S"/X`$0C^`%`*#A/?K_ZP8`H.$L^O_K[`&?Y040H.$``(_@
MROO_ZP4`H.&J_O_K__[_Z@"0E^78^?_K`!"@X0D`H.$L_?_K`+!0XI?__QJ5
M___J`#"@XP`@H.,`,(WE!P"@X0`PH..?^?_K900`ZP"@H.$"*:#C"Q"@X0<`
MH.$"^O_K`"!0XAT``,H'`*#A1'!$XO?Y_^L*$*#A!P"@X3"@1.*\!`#K"K"@
MX5R!G^4(@(_@"@"@X0$@U^0($*#A`9")X@_Z_^L4`%GC`J"*XO?__QH`,*#C
M"#!$Y3`QG^4P$9_E`S"/X`0PC>4H,9_E`+"-Y0,PC^`&(*#A`1"/X,#__^H+
M$*#A"@"@X5$$`.O7___J!!&?Y00!G^4!$(_@``"/X(K[_^MR^?_K]#"?Y?00
MG^4#,(_@"0"-Z.PPG^4&(*#A`S"/X`$0C^`%`*#A[/G_Z]A`G^78<)_EV)"?
MY01`C^`'<(_@"9"/X`<=H.,%`*#AT?G_ZP$`<..C__\:R_G_ZP`PD.41`%/C
MG___&ECY_^L!H(KB`02-Z`B0C>4$,*#A!B"@X0<0H.$%`*#AU/G_Z^S__^H"
MV8WB_-"-XO"/O>@(60$`+`$``#!:`0!&&0``JAD```P9``#O&```'A@```@!
M``"U&```4Q@``#P8``".%P``"Q@``,`7``"I%P``W18``&85```N%0``AA4`
M`+46``#E%0``<A0```$5``"%%```918``*@5```B%```!A0``)H5```Q%@``
M^$\MZ2PSG^4L(Y_E`S"/X`)`D^<``)3EI_G_ZP!0H.$``)3EI/G_ZV0PU>5E
M,,#E"`.?Y0``C^`!^__K``!0XP4```H`,-#E,0!3XP(``!H!,-#E``!3XP``
M``IG_?_K``"4Y93Y_^O4$I_E"S"@XP$@H.,!$(_@1/G_ZP``4.,=```:``"4
MY8OY_^NT$I_E`S"@XP$@H.,!$(_@._G_ZP!04.)-```:``"4Y8+Y_^N4$I_E
M`S"@XP$@H.,!$(_@,OG_ZP!04.)A```*?`*?Y0``C^#:^O_K`&!0XE$```H`
M`)3E=/G_ZP8@H.$,,)7E`!"3Y2OY_^M5``#J`5"@XPPPD.5(@I_E&'"3Y422
MG^4(@(_@!#"8Y0%@1>(%`%/A``"4Y08``-IC^?_K`#"@XP8@H.$'$*#AZOC_
MZP"P4.((```:$#*?Y0,PC^`$()/E`2!"X@(`5N')__\:`6"@XP-0H.$8``#J
M"#"8Y0`@F^4%H9/G"#"2Y0DP`^`!"U/C#!"2!08```H``)3E2OG_ZP`0F^4"
M,*#C`""@XU+Y_^L`$*#A"@"@X<7X_^L``%#CX___&@%0A>+5___J/OG_ZP<0
MH.&=^/_K`6"&X@0PE>4``)3E!@!3X??__\JH___J``"4Y33Y_^L,,)7E;"&?
MY0`0D^4"((_@ZOC_ZPPPE>4`,)/E"#"3Y0$%$^.E__\*``"4Y2CY_^L,,)7E
M`!"3Y;;X_^N?___JU/O_ZP!@4.(``)3E*```"A_Y_^L,,)7E!B"@X0`0D^76
M^/_K!@"@X0WY_^L``)3E%_G_ZP!0H.$``)3E%/G_Z_00G^4!(*#C`1"/X'KX
M_^OH()_E`!"@X0(@C^`%`*#AQOC_ZP``E.4)^?_K`#"@XV4PP.7(`)_ER$"?
MY0``C^!E^O_K!$"/X```4.,,`(3E#@``&@@`E.6B_?_K``!0XPP`A.4)```:
MG`"?Y0``C^!M^/_K]OC_ZY`PG^4#,(_@"""3Y0PPE>4`()+E??__ZGQ`G^4'
M':#C!$"/X`P`E.7<^/_K`2"`XA$`4.,!`%(3`#"@X?B/O9@($)3E5`"?Y0P@
ME.4`$)'E``"/X%;X_^M84@$`(`$``!43``!;%```/!0``!\4``!'$@``]%(!
M```$(`"\4@$`XA(``&T2``!R$@``:A```%A1`0`D$@``(%$!``11`0#I$0``
M<$`MZ0!`H.%:_/_K4OS_ZP!0H.$?_?_K``!0XP``5!-P@+T(`##4Y0``4^-P
M@+T('!"?Y04`H.$!$(_@;/C_ZP``5>%P@+T8!`"@X7!`O>C$^O_J2!```/!/
M+>G(.Y_ER"N?Y57?3>(#,(_@`C"3YPP@C>("P*#A!#"-Y0`PD^5<X(#B3#&-
MY1PP@.($$)/D,1^_Y@,`7N$$$(SD^O__&D#`H.,"$*#A(."1Y30PD>4$((+B
M#C`CX`C@D>4`$)'E#C`CX`$P(^#C/Z#A`<!<XCPP@N7R__\:5#N?Y0S@G>4$
M<)#E"%"`XF`!E>@`D)#E`^".X`8@)>`'(`+@".".X.GMCN`&("+@9T&@X0+@
MCN`0()WE!,`EX`G`#.`#((+@!<`LX`8@@N!IH:#A`L",X!0@G>4*$"3@#A`!
MX`,@@N`%((+@!!`AX.[-C.`"$('@;N&@X1@@G>4.L"K@#+`+X`,@@N#L'8'@
M!"""X&S!H.$*L"O@'$"=Y0*PB^`,("[@`T"$X`$@`N`*H(3@#B`BX.&]B^`*
M((+@81&@X2"@G>4!0"S@`Z"*X`M`!.#K+8+@#N"*X&NQH.$,0"3@)*"=Y0Y`
MA.`+X"'@`Z"*X`+@#N`,P(K@`>`NX.)-A.`,X([@8B&@X2C`G>4"H"O@`\",
MX`2@"N`!$(S@"Z`JX.3MCN`!H(K@9$&@X2P0G>4$P"+@`Q"!X`[`#.`+L('@
M`L`LX.ZMBN`+P(S@;N&@X3"PG>4.$"3@`["+X`H0`>#JS8S@`B"+X&JAH.$$
M$"'@-+"=Y0(0@>`*("[@`["+X`P@`N#L'8'@!$"+X&S!H.$.("+@.+"=Y00@
M@N`,0"K@`["+X`%`!.#A+8+@#N"+X&$1H.$*0"3@/+"=Y0Y`A.`!X"S@`["+
MX`+@#N`*H(O@#.`NX.)-A.`*X([@8B&@X4"@G>4"L"'@`Z"*X`2P"^`,P(K@
M`;`KX.3MCN`,L(O@9$&@X43`G>4$H"+@`\",X`Z@"N#NO8O@`1",X&[AH.$"
MH"K@2,"=Y0&@BN`.$"3@`\",X`L0`>#KK8K@!!`AX&NQH.$"((S@3,"=Y0(@
M@>`+$"[@`\",X`H0`>#J+8+@#A`AX&JAH.$$0(S@4,"=Y01`@>`*$"O@`\",
MX`(0`>`+$"'@#N",X.)-A.`.X('@8B&@X500G>4"P"K@`Q"!X`3`#.`+L('@
M"L`LX.3MCN`+P(S@9$&@X5BPG>4$$"+@`S"+X`X0`>`*H(/@`A`AX(0XG^4*
M$('@7*"=Y>[-C.`#H(K@;N&@X0(@BN`.H"3@#*`JX`H@@N!@H)WE[!V!X`.@
MBN!LP:#A!$"*X`R@+N`!H"K@"D"$X&2@G>7A+8+@`Z"*X&$1H.$.X(K@`:`L
MX`*@*N`*X([@:*"=Y>)-A.`#H(K@8B&@X0S`BN`"H"'@!*`JX`K`C.!LH)WE
MY.V.X`.@BN!D0:#A`1"*X`2@(N`.H"K@"A"!X'"@G>7NS8S@`Z"*X&[AH.$"
M((K@#J`DX`R@*N`*((+@=*"=Y>P=@>`#H(K@;,&@X01`BN`,H"[@`:`JX`I`
MA.!XH)WEX2V"X`.@BN!A$:#A#N"*X`&@+.`"H"K@"N".X'R@G>7B383@`Z"*
MX&(AH.$,P(K@`J`AX`2@*N`*P(S@@*"=Y>3MCN`#H(K@9$&@X0$0BN`$H"+@
M#J`JX`H0@>"$H)WE[LV,X`.@BN!NX:#A`B"*X`Z@).`,H"K@"B""X(B@G>7L
M'8'@`Z"*X&S!H.$$0(K@#*`NX`&@*N`*0(3@C*"=Y>$M@N`#H(K@81&@X0[@
MBN`!H"S@`J`JX`K@CN"0H)WEXDV$X`.@BN!B(:#A#,"*X`*@(>`$H"K@"L",
MX)2@G>7D[8[@`Z"*X&1!H.&8L)WE`1"*X`2@(N#NS8S@#J`JX`.PB^!NX:#A
M"A"!X`*PB^"<H)WE#B`DX`P@(N#L'8'@`K"+X&S!H.$#H(K@H""=Y02@BN`,
M0"[@X;V+X`%`).`#((+@81&@X0[@@N`!("S@"R`BX`+@CN"D()WE!*"*X.NM
MBN`#((+@:[&@X0S`@N`+("'@"B`BX`+`C."H()WEZNV.X`,P@N!JH:#A`1"#
MX`HP*^#NS8S@#C`CX&[AH.$.((KA`Q"!X`P@`N`.,`K@`R""X:Q`G>7D-9_E
M[!V!X`-`A.!LP:#A"["$X`Q`CN$+((+@`4`$X`RP#N`+0(3AL+"=Y>$M@N`#
ML(O@81&@X0J@B^`*0(3@`:",X0&P#.`"H`K@"Z"*X;2PG>7B383@`["+X&(A
MH.$.X(O@#N"*X`*@@>$"L`'@!*`*X`N@BN&XL)WEY.V.X`.PB^!D0:#A#,"+
MX`S`BN`$H(+A!+`"X`Z@"N`+H(KAO+"=Y>[-C.`#L(O@;N&@X0$0B^`!$(K@
M#J"$X0ZP!.`,H`K@"Z"*X<"PG>7L'8'@`["+X&S!H.$"((O@`B"*X`R@CN$,
ML`[@`:`*X`N@BN'$L)WEX2V"X`.PB^!A$:#A!$"+X`1`BN`!H(SA`;`,X`*@
M"N`+H(KAR+"=Y>)-A.`#L(O@8B&@X0[@B^`.X(K@`J"!X0*P`>`$H`K@"Z"*
MX<RPG>7D[8[@`["+X&1!H.$,P(O@#,"*X`2@@N$$L`+@#J`*X`N@BN'0L)WE
M[LV,X`.PB^!NX:#A`1"+X`$0BN`.H(3A#K`$X`R@"N`+H(KAU+"=Y>P=@>`#
ML(O@;,&@X0(@B^`"((K@#*".X0RP#N`!H`K@"Z"*X=BPG>7A+8+@`["+X&$1
MH.$$0(O@!$"*X`&@C.$!L`S@`J`*X`N@BN'<L)WEXDV$X`.PB^!B(:#A#N"+
MX`[@BN`"H('A`K`!X`2@"N`+H(KAX+"=Y>3MCN`#L(O@9$&@X0S`B^`,P(K@
M!*""X02P`N`.H`K@"Z"*X>2PG>7NS8S@`["+X&[AH.$!$(O@`1"*X`Z@A.$.
ML`3@#*`*X`N@BN'HL)WE[!V!X`.PB^!LP:#A`B"+X`(@BN`,H([A#+`.X`&@
M"N`+H(KA[+"=Y>$M@N`#L(O@81&@X01`B^`$0(K@`:",X0&P#.`"H`K@"Z"*
MX?"PG>7B383@`["+X&(AH.$.X(O@#N"*X`*@@>$"L`'@!*`*X`N@BN'TL)WE
MY.V.X`.PB^!D0:#A#,"+X`S`BN`$H(+A#K`*X`2@`N`*H(OA^+"=Y>[-C.`#
M,(O@`1"#X`$0BN#<,I_E[*V!X/P0G>5NX:#A`Q"!X`(@@>`.$"3@#!`AX`$@
M@N``$9WE;,&@X0,0@>`$0('@#!`NX`H0(>`!0(3@!!&=Y>HM@N`#$('@:J&@
MX0[@@>`*$"S@`A`AX`'@CN`($9WEXDV$X`,0@>!B(:#A#,"!X`(0*N`$$"'@
M`<",X`P1G>7D[8[@`Q"!X&1!H.$*H('@!!`BX`X0(>`!H(K@$!&=Y>[-C.`#
M$('@;N&@X0(@@>`.$"3@#!`AX`$0@N`4(9WE[*V*X`,@@N!LP:#A!$""X`P@
M+N`*("+@`D"$X!@AG>7J'8'@`R""X&JAH.$.X(+@"B`LX`$@(N`"(([@'.&=
MY>%-A.`#X([@81&@X0S`CN`!X"K@!.`NX`[`C.`@X9WEY"V"X`/@CN!D0:#A
M"J".X`3@(>`"X"[@#N"*X"2AG>7BS8S@`Z"*X&(AH.$!$(K@`J`DX`R@*N#L
M[8[@"A"!X&RAH.$HP9WE[AV!X`/`C.`$0(S@"L`BX`[`+.`,P(3@+$&=Y6[A
MH.$#0(3@`B"$X`Y`*N`!0"3@X<V,X`0@@N!A0:#A,!&=Y>PM@N`#$('@"A"!
MX`2@+N`,H"K@"A"!X#2AG>5LP:#A`Z"*X`[@BN`,H"3@`J`JX.(=@>`*X([@
M8J&@X3@AG>7A[8[@`R""X`0@@N`*0"S@`4`DX`0@@N`\09WE81&@X0-`A.`,
MP(3@`4`JX`Y`).`$P(S@0$&=Y>XM@N`#0(3@;N&@X0J@A.`.0"'@`D`DX`2@
MBN!$09WEXLV,X`-`A.!B(:#A`1"$X`)`+N`,0"3@!!"!X$A!G>7LK8K@`S"$
MX`F0@^!LP:#A#N")X`R0(N`*D"G@ZAV!X`G@CN#A[8[@!#"=Y0(@B.``X(#E
M$""`Y4PAG>4`,)/E`7"'X&I1A>`,P(;@`P!2X01P@.4(4(#E#,"`Y0````K6
M]?_K5=^-XO"/O>AX3@$`+`$``)EY@EJAZ]ENW+P;C];!8LH00"WI8`"@XU#U
M_^LH$)_E*""?Y2C`G^4HX)_E!E"`Z"0@G^40((#E`""@XQ0@@.48((#E7""`
MY1"`O>@!(T5GB:O-[_[<NIAV5#(0\.'2P_!!+>D"8*#A`%"@X10PD.6"(:#A
M`C"3X!@@D"44,(#E`2""(A@@@"48,)#E''"%XJ8^@^`8,(#E7`"0Y0``4.,9
M```*0$!@X@0`5N$``(?@!D"@L0$`4.$#```J!#"`X`,`4>$````J\`#PYP$`
M4.$$@('@`0``F@@`4.'Y__\Z!""@X8SU_^M<,)7E`S"$X$``4^-<,(7E\(&]
M&`4`H.''_/_K"!"@X01@1N!<@(7B$@``Z@<`4>$!``":"`!1X>C__SH'`%'A
M0#"!X@$``"H#`%?AX___.@%`H.$'(*#A!!"4Y`,`5.$$$(+D^___&@4`H.&R
M_/_K!!"@X4!@1N(_`%;CZO__R@<`4>$"``":!C"'X`,`4>'2__\Z!P!1X0(`
M`"H&,('@`P!7X<W__SH&(*#A!P"@X5_U_^M<8(7E\(&]Z/!!+>D<@('B%#"1
MY1A@D>4!0*#A?Q#@XS-_O^:C,:#A/S`#X@$@@^(X`%+C`%"@X0,0R.<"`(C@
M-F^_YC@@8M(`$*#3!P``VD`@8N(`$*#CT/3_ZP0`H.&(_/_K.""@XP`0H.,(
M`*#ARO3_ZP0`H.'T9<3A@?S_ZP,PU.4$`*#A`##%Y;(PU.$!,,7E`#"4Y2,T
MH.$",,7E`#"4Y0,PQ>4',-3E!##%Y;8PU.$%,,7E!#"4Y2,TH.$&,,7E!#"4
MY0<PQ>4+,-3E"##%Y;HPU.$),,7E"#"4Y2,TH.$*,,7E"#"4Y0LPQ>4/,-3E
M###%Y;XPU.$-,,7E##"4Y2,TH.$.,,7E##"4Y0\PQ>43,-3E$##%Y;(QU.$1
M,,7E$#"4Y2,TH.$2,,7E$#"4Y1,PQ>7P0;WH_?3_Z@%`+>D!0+WH'O\OX7!E
M<FQX<VDN8P!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```+BX`
M)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ
M4$%2.CI"3T]4`"]P<F]C+R5I+R5S`&5X90!005)?5$5-4`!005)?4%)/1TY!
M344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])
M3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!
M4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!
M4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%2
M7T-,14%./0`Q`$Q$7TQ)0E)!4EE?4$%42`!365-414T`)3`R>``E<R5S)7,E
M<P!P87(M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H`)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E
M;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2.CI0
M86-K97(Z.E9%4E-)3TX`,2XP-#D`56YA8FQE('1O(&-R96%T92!C86-H92!D
M:7)E8W1O<GD`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`M90`M+0!54T52`%5315).
M04U%`%1%35!$25(`5$U0`"]T;7``979A;"`G97AE8R`O=7-R+V)I;B]P97)L
M("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@
M<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N
M("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D
M=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D
M=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD
M('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA
M;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@
M9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["B1005)?34%'24,@/2`B
M7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE
M="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R
M7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@
M)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G
M;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE
M(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*
M;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE*2!["B1M
M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E("1C:'5N
M:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T["GT@96QS
M92!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]"G=H:6QE
M("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:RA?1D@L("1M86=I8U]P;W,L(#`I
M.PIR96%D*%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-
M04=)0RDI.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I
M*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O
M<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@/"`P.PIS
M965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T
M.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F
M*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0[
M"G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%
M(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N
M<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F
M=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968[
M"FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N
M*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E
M>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`]
M(%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS
M:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%
M3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B
M87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE
M;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]
M"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@
M/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]
M"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@
M*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@
M;W(@(21M;V1U;&4["FUY("1I;F9O(#T@9&5L971E("1R97%U:7)E7VQI<W1[
M)&UO9'5L97T@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O
M)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN
M960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?
M=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1I
M;F9O+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L
M<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1I;F9O+3Y[8W)C?2YP
M;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M
M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H
M)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D
M.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY
M("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*
M=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T10
M04XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E
M("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL
M96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@
M(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@
M("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM
M>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T
M92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@
M8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6
M>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@
M)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q
M=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T
M86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!
M4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8[
M"B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@
M(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE
M("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH
M+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I
M;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*
M?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*
M?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@
M97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("="
M)RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD
M<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L
M("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*
M?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI
M9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L
M971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2
M.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]
M"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY
M("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\)RP@
M)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E
M*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@
M)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@
M86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*
M)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS
M.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@
M)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D
M<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A
M<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<
M,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/
M7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D
M:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I
M(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO
M861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R
M="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*
M)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I
M8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`]
M(")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M
M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I
M("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD[
M"B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I
M.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!
M3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#
M;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S
M>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A
M;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?
M97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I
M('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@
M>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD
M9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#
M8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*
M?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@
M*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@
M(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I
M.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N
M;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD
M("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ
M<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I
M;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@
M>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%
M+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB
M:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<
M+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^
M;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ
M<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD
M9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M
M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP
M=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT
M*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*
M)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H
M(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI
M('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96XH;7D@)&9H
M+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0[
M"GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A
M8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L
M96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H
M+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL
M97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U
M:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E
M<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*
M)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R
M(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@
M*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%
M35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L
M9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@
M)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R
M>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@
M=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF
M:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C
M:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q
M.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!
M4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F
M("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H
M<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E
M>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT
M<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE
M;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P
M-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N
M;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB
M('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I
M<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD
M,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U
M8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE
M.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I
M<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE
M<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@
M<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO
M861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER
M92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR
M97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L
M93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*
M<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E
M<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$
M:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,[
M"F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!]
M.PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I
M<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I
M93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)
M3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U
M=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P
M87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM
M87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%
M35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL
M97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*
M;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T
M<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS
M,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA
M;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P
M=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@
M)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?
M+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N
M=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M
M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V
M.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*
M<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E
M('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM
M>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM>2`D9F@L("(\
M(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2`O+R`D;71I;64[
M"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD9&EG97-T(CL*
M?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM0
M05)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA
M<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@
M*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@
M/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*
M;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G
M/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@
M)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@
M)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4[
M"G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP
M;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M
M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM0
M05)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD
M<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X
M*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE
M(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R
M(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF
M("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US
M("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P
M<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H
M(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6
M>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D
M9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D
M96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O
M9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T
M*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS
M=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!
M4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_
M($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@
M5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N
M86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#
M;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!
M3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])
M3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!
M3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLG4$%2
M7R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I
M('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I
M9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L
M96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@
M*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*
M96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D
M=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.
M(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?
M0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T
M.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92![
M"G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N
M9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]
M"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"90
M05(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA
M;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````"<%P``$!<```$````!`````0```.@"```/````
MC@0```P```!@$```#0```.`^```9````P'T!`!L````$````&@```,1]`0`<
M````!````/7^_V\L`0``!0```-0(```&````%`(```H```"L!```"P```!``
M```5``````````,```"X?@$``@```/`!```4````$0```!<```!P#@``$0``
M`(`-```2````\````!,````(````&`````````#[__]O`0``"/K__V\0````
M`````````````````````````````````````````````````````,A]`0``
M`````````&P0``!L$```;!```&P0``!L$```;!```&P0``!L$```;!```&P0
M``!L$```;!```&P0``!L$```;!```&P0``!L$```;!```&P0``!L$```;!``
M`&P0``!L$```;!```&P0``!L$```;!```&P0``!L$```;!```&P0``!L$```
M;!```&P0``!L$```;!```&P0``!L$```;!```&P0``!L$```;!```&P0``!L
M$```;!```&P0``!L$```;!```&P0``!L$```;!```&P0``!L$```;!```&P0
M``!L$```;!```&P0``!L$```;!```&P0``!L$```:!,`````````````X#X`
M````````````8!``````````````````````````````````````````````
M````````````@`$`_____\Y!```9/P```````/H_``#S/P``PD$``!!```#*
M00```````+1!``"Y00```````--!``!'0T,Z("A!;'!I;F4@."XS+C`I(#@N
M,RXP`$$R````865A8FD``2@````%-EI+``8'"`$)`0H"$@03`10!%0$7`Q@!
M&@(<`1X$(@%$`0`N<VAS=')T86(`+FEN=&5R<``N9VYU+FAA<V@`+F1Y;G-Y
M;0`N9'EN<W1R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD
M>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T
M97,`````````````````````````````````````````````````````````
M"P````$````"````%`$``!0!```8```````````````!`````````!,```#V
M__]O`@```"P!```L`0``Z`````,`````````!`````0````=````"P````(`
M```4`@``%`(``,`&```$`````P````0````0````)0````,````"````U`@`
M`-0(``"L!``````````````!`````````"T````)`````@```(`-``"`#0``
M\`````,`````````!`````@````V````"0```$(```!P#@``<`X``/`!```#
M````$`````0````(````/P````$````&````8!```&`0```,````````````
M```$`````````#H````!````!@```&P0``!L$```_`(`````````````!```
M``0```!%`````0````8```!H$P``:!,``'@K``````````````0`````````
M2P````$````&````X#X``.`^```,```````````````$`````````%$````!
M`````@```.P^``#L/@``2#T``````````````0````````!9`````0````(`
M```T?```-'P```0```````````````0`````````8P````X````#````P'T!
M`,!]```$```````````````$````!````&\````/`````P```,1]`0#$?0``
M!```````````````!`````0```![````!@````,```#(?0$`R'T``/`````$
M``````````0````(````A`````$````#````N'X!`+A^``!(`0``````````
M```$````!````(D````!`````P````"``0``@```/```````````````!```
M``````"/````"`````,````\@`$`/(```#`0``````````````0`````````
ME`````$````P`````````#R````:```````````````!`````0```)T````#
M``!P``````````!6@```,P```````````````0`````````!`````P``````
>````````B8```*T```````````````$`````````
